import { TypeOptions } from "@progress/sitefinity-webservices-sdk/dist/sitefinity-webservices-sdk";
/**
 * Interface for Sitefinity Service operations.
 */
export interface ISitefinityService {
    /**
     * Writes a value to the service.
     * @param value - The value to be written. This can be of any type.
     */
    writeValue(value: any): void;
    /**
     * Sets validation errors on the service.
     * @param errors - The errors to set. This can be of any type, typically an object or an array representing validation errors.
     */
    setErrors(errors: any): void;
}
/**
 * Interface for SitefinityRestService, providing methods for interacting with Sitefinity CMS data.
 */
export interface ISitefinityRestService {
    /**
     * Configures the service with the given Sitefinity data type options.
     * @param sfData - The type options for configuring the Sitefinity SDK instance.
     */
    configure(sfData: TypeOptions): void;
    /**
     * Retrieves a collection of items from Sitefinity CMS.
     * @template T - The type of the expected data.
     * @param key - (Optional) The key or ID for the specific item.
     * @param action - (Optional) The action to perform during the retrieval.
     * @param fallbackProperties - (Optional) A list of properties to use as a fallback if the main retrieval fails.
     * @returns A promise that resolves to the retrieved collection of items.
     */
    get<T>(key?: string, action?: string, fallbackProperties?: string[]): Promise<T>;
    /**
     * Retrieves a single item from Sitefinity CMS based on the provided key.
     * @template T - The type of the expected data.
     * @param key - The unique identifier for the item to retrieve.
     * @param action - (Optional) The action to perform during the retrieval.
     * @param fallbackProperties - (Optional) A list of properties to use as a fallback if the main retrieval fails.
     * @returns A promise that resolves to the retrieved item.
     */
    getSingle<T>(key: string, action?: string, fallbackProperties?: string[]): Promise<T>;
    /**
     * Creates a new item in Sitefinity CMS.
     * @template T - The type of the expected data.
     * @param key - (Optional) The key or ID for the specific item.
     * @param action - (Optional) The action to perform during creation.
     * @param data - (Optional) The data to be created.
     * @param fallbackProperties - (Optional) A list of properties to use as a fallback if the creation fails.
     * @returns A promise that resolves to the created item.
     */
    create<T>(key?: string, action?: string, data?: any, fallbackProperties?: string[]): Promise<T>;
    /**
     * Updates an existing item in Sitefinity CMS.
     * @template T - The type of the expected data.
     * @param key - (Optional) The key or ID for the specific item.
     * @param action - (Optional) The action to perform during the update.
     * @param data - (Optional) The data to be updated.
     * @param fallbackProperties - (Optional) A list of properties to use as a fallback if the update fails.
     * @param saveTemp - (Optional) A boolean to indicate if the update should be saved temporarily.
     * @returns A promise that resolves to the updated item.
     */
    update<T>(key?: string, action?: string, data?: any, fallbackProperties?: string[], saveTemp?: boolean): Promise<T>;
    /**
     * Deletes an item from Sitefinity CMS.
     * @template T - The type of the expected data.
     * @param key - (Optional) The key or ID for the specific item.
     * @param action - (Optional) The action to perform during deletion.
     * @param fallbackProperties - (Optional) A list of properties to use as a fallback if the deletion fails.
     * @returns A promise that resolves when the item is successfully deleted.
     */
    delete<T>(key?: string, action?: string, fallbackProperties?: string[]): Promise<T>;
    /**
     * Performs an operation on a Sitefinity CMS item.
     * @template T - The type of the expected data.
     * @param key - (Optional) The key or ID for the specific item.
     * @param action - (Optional) The action to perform during the operation.
     * @param parentId - (Optional) The ID of the parent item, if applicable.
     * @param fallbackProperties - (Optional) A list of properties to use as a fallback if the operation fails.
     * @returns A promise that resolves to the result of the operation.
     */
    operation<T>(key?: string, action?: string, parentId?: string, fallbackProperties?: string[]): Promise<T>;
    /**
     * Retrieves a specific property of an item from Sitefinity CMS.
     * @template T - The type of the expected data.
     * @param property - The name of the property to retrieve.
     * @param key - (Optional) The key or ID for the specific item.
     * @param action - (Optional) The action to perform during the retrieval.
     * @param fallbackProperties - (Optional) A list of properties to use as a fallback if the retrieval fails.
     * @returns A promise that resolves to the property value.
     */
    getProperty<T>(property: string, key?: string, action?: string, fallbackProperties?: string[]): Promise<T>;
    /**
     * Creates a related item in Sitefinity CMS.
     * @template T - The type of the expected data.
     * @param property - The name of the related property.
     * @param link - The identifier (string or number) of the item to link to.
     * @param key - (Optional) The key or ID for the specific item.
     * @param action - (Optional) The action to perform during creation.
     * @param fallbackProperties - (Optional) A list of properties to use as a fallback if the creation fails.
     * @returns A promise that resolves to the created related item.
     */
    createRelated<T>(property: string, link: string | number, key?: string, action?: string, fallbackProperties?: string[]): Promise<T>;
    /**
     * Deletes a related item from Sitefinity CMS.
     * @template T - The type of the expected data.
     * @param property - The name of the related property.
     * @param relatedId - The identifier of the related item to delete.
     * @param key - (Optional) The key or ID for the specific item.
     * @param action - (Optional) The action to perform during deletion.
     * @param fallbackProperties - (Optional) A list of properties to use as a fallback if the deletion fails.
     * @returns A promise that resolves when the related item is successfully deleted.
     */
    deleteRelated<T>(property: string, relatedId: string, key?: string, action?: string, fallbackProperties?: string[]): Promise<T>;
    /**
     * Deletes a related item from Sitefinity CMS by its ID.
     * @template T - The type of the expected data.
     * @param property - The name of the related property.
     * @param relatedId - The identifier of the related item to delete.
     * @param key - (Optional) The key or ID for the specific item.
     * @param action - (Optional) The action to perform during deletion.
     * @param fallbackProperties - (Optional) A list of properties to use as a fallback if the deletion fails.
     * @returns A promise that resolves when the related item is successfully deleted.
     */
    deleteRelatedById<T>(property: string, relatedId: string, key?: string, action?: string, fallbackProperties?: string[]): Promise<T>;
    /**
     * Retrieves related items from Sitefinity CMS for a specific property.
     * @template T - The type of the expected data.
     * @param property - The name of the related property.
     * @param key - (Optional) The key or ID for the specific item.
     * @param action - (Optional) The action to perform during retrieval.
     * @param fallbackProperties - (Optional) A list of properties to use as a fallback if the retrieval fails.
     * @returns A promise that resolves to the retrieved related items.
     */
    getRelated<T>(property: string, key?: string, action?: string, fallbackProperties?: string[]): Promise<T>;
    /**
     * Retrieves a related item by its ID from Sitefinity CMS.
     * @template T - The type of the expected data.
     * @param property - The name of the related property.
     * @param relatedId - The identifier of the related item to retrieve.
     * @param key - (Optional) The key or ID for the specific item.
     * @param action - (Optional) The action to perform during retrieval.
     * @param fallbackProperties - (Optional) A list of properties to use as a fallback if the retrieval fails.
     * @returns A promise that resolves to the retrieved related item.
     */
    getRelatedById<T>(property: string, relatedId: string, key?: string, action?: string, fallbackProperties?: string[]): Promise<T>;
    /**
     * Uploads a file or content to Sitefinity CMS.
     * @template T - The type of the expected data.
     * @param content - The content to upload.
     * @param contentType - The MIME type of the content.
     * @param name - The name of the file or content.
     * @param payload - An object representing additional data to send with the upload.
     * @param uploadProperties - A dictionary of upload properties.
     * @param publish - Indicates if the uploaded content should be published immediately.
     * @param key - (Optional) The key or ID for the specific item.
     * @param action - (Optional) The action to perform during upload.
     * @param fallbackProperties - (Optional) A list of properties to use as a fallback if the upload fails.
     * @returns A promise that resolves to the uploaded content's metadata.
     */
    upload<T>(content: string, contentType: string, name: string, payload: object, uploadProperties: {
        [key: string]: string;
    }, publish: boolean, key?: string, action?: string, fallbackProperties?: string[]): Promise<T>;
}
