import { Sitefinity } from "@progress/sitefinity-webservices-sdk/dist/sitefinity-webservices-sdk";
/**
 * A function type that represents an action to be performed by a rich text editor tool in Sitefinity.
 *
 * This function is triggered by an event within the rich text editor and uses the provided
 * Sitefinity context (`SfToolContext`) to perform specific operations, such as manipulating content
 * or interacting with the editor's environment.
 *
 * @param ev - The event that triggered the tool's action. Typically, this could be a click event or any other user interaction event.
 * @param sfContext - The context object provided by Sitefinity, containing necessary data and state for the tool's operation.
 */
export type RichTextEditorToolFunction = (ev: Event, sfContext: SfToolContext) => void;
/**
 * Represents the context provided by Sitefinity to rich text editor tools.
 *
 * The context includes information about the current culture, the entity set being edited,
 * and the specific data item that is being manipulated. This context enables the tools to
 * perform operations that are relevant to the current editing session.
 */
export interface SfToolContext {
    /**
     * The specific data item that is being edited or manipulated by the tool.
     * This object contains the actual data along with associated metadata.
     */
    dataItem: DataItem;
    /**
     * An instance of the Sitefinity REST SDK, providing methods and properties
     * to interact with the Sitefinity REST API. This SDK is used to perform operations
     * like fetching, updating, or deleting data within the Sitefinity CMS.
     */
    restSdk: Sitefinity;
}
/**
 * Represents a data item in Sitefinity, including its actual content, metadata, provider, and culture information.
 *
 * A `DataItem` encapsulates the core content along with additional metadata that provides context about the content's structure,
 * the data provider, and the associated culture. This information is crucial for tools that need to interact with the
 * content in a structured manner.
 */
export interface DataItem extends EntityData {
    /**
     * The actual content or data of the item.
     * This could be text, media, or any other form of content managed by the editor.
     */
    readonly data: any;
    /**
     * Metadata associated with this item, which describes the data's structure and additional properties.
     * This metadata helps in understanding the context and structure of the data item.
     */
    readonly metadata: Entity;
    /**
     * The name of the provider that supplies this data item.
     * Providers are responsible for retrieving and saving the data associated with the item.
     */
    readonly provider: string;
    /**
     * The culture associated with this item, indicating the locale of the content.
     * This is especially important in multilingual applications where content varies by culture.
     */
    readonly culture: string;
    /**
     * The unique identifier for this data item. Returns `null` if the item has no key.
     * This key is often used to retrieve or update the specific item within its entity set.
     */
    readonly key: string;
    /**
     * The title or primary short text field of the item, often used as a display name or headline.
     * This is typically the most prominent text associated with the data item.
     */
    readonly title: string;
}
/**
 * Represents metadata and information about an entity within Sitefinity.
 *
 * An `EntityData` object provides access to metadata, the data provider's name, and the associated culture.
 * It serves as a base for more complex data structures like `DataItem`.
 */
export interface EntityData {
    /**
     * Metadata associated with the entity, describing its structure and properties.
     * This metadata is essential for understanding the schema and fields of the entity.
     */
    readonly metadata: Entity;
    /**
     * The name of the provider that supplies this entity's data.
     * This identifies the source from which the entity's data is retrieved and stored.
     */
    readonly provider: string;
    /**
     * The culture associated with this entity, indicating the locale of the content.
     * Culture information helps in handling multilingual data within the entity.
     */
    readonly culture: string;
}
/**
 * Contains metadata and information about a specific entity type in Sitefinity.
 *
 * An `Entity` provides key details about the entity type, including its unique identifier, the entity set it belongs to,
 * and its full type name. This information is crucial for tools and systems that need to work with specific types of content.
 */
export interface Entity {
    /**
     * The key of the entity, typically used as a unique identifier (e.g., "Id").
     * This key is used to uniquely identify the entity within its set.
     */
    readonly key: string;
    /**
     * The name of the entity set that this entity belongs to (e.g., "newsitems").
     * This indicates the collection of entities to which this entity is associated.
     */
    readonly setName: string;
    /**
     * The full type name of the entity (e.g., "Telerik.Sitefinity.News.Model.NewsItem").
     * This is the fully qualified name of the entity's class or type, used for reflection and other type-specific operations.
     */
    readonly typeFullName: string;
}
/**
 * A dictionary that maps tool names to their corresponding rich text editor tool functions.
 *
 * This interface allows you to define a collection of tools for a rich text editor, where each tool
 * is associated with a specific function that performs an action within the editor.
 */
export interface RteFunctionDict {
    /**
     * The key represents the tool's name, and the value is the function that gets executed when the tool is used.
     * Each function is responsible for a specific action, such as formatting text or inserting media.
     */
    [key: string]: RichTextEditorToolFunction;
}
/**
 * Represents the namespace within Sitefinity that contains rich text editor tools.
 *
 * The `SfNamespace` interface includes a dictionary of tools (`rteTools`) and a callback function
 * (`rteToolsIconsSetupCallback`) that is responsible for setting up tool icons in the editor's UI.
 */
export interface SfNamespace {
    /**
     * A dictionary of rich text editor tools, where each key is the tool's name, and the value is its corresponding function.
     * This allows for dynamic addition and management of tools within the editor.
     */
    rteTools: RteFunctionDict;
    /**
     * A callback function that is invoked to set up the icons for the rich text editor tools.
     * This function ensures that the icons are properly configured and displayed in the editor's toolbar.
     */
    rteToolsIconsSetupCallback: () => void;
}
/**
 * Extends the global `Window` interface to include Sitefinity's namespace for rich text editor tools.
 *
 * This allows for rich text editor tools to be accessed globally via the `sf` property on the `Window` object,
 * facilitating the integration and management of these tools across the application.
 */
export interface SfWindow extends Window {
    sf: SfNamespace;
}
